@@ -1,10 +1,10 @@
 """
-Blah Blah
+Main Classes for the PeakRDL Python
 """
 import os
 from pathlib import Path
 from shutil import copyfile
-from typing import List
+from typing import List, NoReturn
 from glob import glob
 
 import autopep8 # type: ignore
@@ -22,8 +22,16 @@ from .systemrdl_node_utility_functions import get_reg_readable_fields, get_reg_w
     get_memory_max_entry_value_hex_string, get_array_typecode, get_memory_width_bytes, \
     get_field_default_value
 
+from .safe_name_utility import is_safe_field_name, is_safe_register_name, is_safe_memory_name, \
+    is_safe_regfile_name, is_safe_addrmap_name, get_python_path_segments, python_field_name
+
 file_path = os.path.dirname(__file__)
 
+class PythonExportTemplateError(Exception):
+    """
+    Exception for hading errors in the templating
+    """
+
 class PythonExporter:
     """
     PeakRDL Python Exporter class
@@ -140,6 +148,14 @@ class PythonExporter:
                 'get_array_typecode': get_array_typecode,
                 'get_memory_width_bytes': get_memory_width_bytes,
                 'get_field_default_value': get_field_default_value,
+                'is_safe_field_name': is_safe_field_name,
+                'is_safe_register_name': is_safe_register_name,
+                'is_safe_memory_name': is_safe_memory_name,
+                'is_safe_regfile_name': is_safe_regfile_name,
+                'is_safe_addrmap_name': is_safe_addrmap_name,
+                'raise_template_error' : self._raise_template_error,
+                'get_python_path_segments' : get_python_path_segments,
+                'python_field_name': python_field_name,
             }
 
             context.update(self.user_template_context)
@@ -252,3 +268,15 @@ class PythonExporter:
                      dst=os.path.join(package_path,
                                       'lib',
                                       filename))
+
+    def _raise_template_error(self, message: str) -> NoReturn:
+        """
+        Helper function to raise an exception from within the templating
+
+        Args:
+            message: message to put in the exception
+
+        Raises: PythonExportTemplateError
+
+        """
+        raise PythonExportTemplateError(message)
